# matsubplots

Better subplots for [matplotlib](https://matplotlib.org).

[![license](https://img.shields.io/github/license/auneri/matsubplots)](https://github.com/auneri/matsubplots/blob/main/LICENSE.md)
[![build](https://img.shields.io/github/actions/workflow/status/auneri/matsubplots/main.yml)](https://github.com/auneri/matsubplots/actions)
[![pypi](https://img.shields.io/pypi/v/matsubplots)](https://pypi.org/project/matsubplots)
[![conda-forge](https://img.shields.io/conda/vn/conda-forge/matsubplots)](https://anaconda.org/conda-forge/matsubplots)

## Getting started

Install using `pip install matsubplots` or `conda install -c conda-forge matsubplots`.

See [example notebooks](https://github.com/auneri/matsubplots/tree/main/examples) for basic instructions.
